# Overview

test desc

This project was generated with [cookiecutter](https://github.com/audreyr/cookiecutter) using [jacebrowning/template-python](https://github.com/jacebrowning/template-python).

[![Unix Build Status](https://img.shields.io/github/actions/workflow/status/megasanjay/evenoddsjy/main.yml?branch=main&label=linux)](https://github.com/megasanjay/evenoddsjy/actions)
[![Windows Build Status](https://img.shields.io/appveyor/ci/megasanjay/evenoddsjy.svg?label=windows)](https://ci.appveyor.com/project/megasanjay/evenoddsjy)
[![Coverage Status](https://img.shields.io/codecov/c/gh/megasanjay/evenoddsjy)](https://codecov.io/gh/megasanjay/evenoddsjy)
[![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/megasanjay/evenoddsjy.svg)](https://scrutinizer-ci.com/g/megasanjay/evenoddsjy)
[![PyPI License](https://img.shields.io/pypi/l/evenoddsjy.svg)](https://pypi.org/project/evenoddsjy)
[![PyPI Version](https://img.shields.io/pypi/v/evenoddsjy.svg)](https://pypi.org/project/evenoddsjy)
[![PyPI Downloads](https://img.shields.io/pypi/dm/evenoddsjy.svg?color=orange)](https://pypistats.org/packages/evenoddsjy)

## Setup

### Requirements

* Python 3.11+

### Installation

Install it directly into an activated virtual environment:

```text
$ pip install evenoddsjy
```

or add it to your [Poetry](https://poetry.eustace.io/) project:

```text
$ poetry add evenoddsjy
```

## Usage

After installation, the package can be imported:

```text
$ python
>>> import evenoddsjy
>>> evenoddsjy.__version__
```
